#!/bin/bash
# Laptop-script rules configaration

################################## STATE OF LAPTOP ##################################
# It can be :
#
# 1-POWER SUPPLY : discharging_false or discharging_true
# 2-BATTERY STATE : status_ok, status_low or status_critical
# 3-LID STATE : lid_closed or lid_open
# 4-PROGRAM EXCEPTION : no_exception or exception
# 5-INACTIVITY :inactive or active

# Example : "discharging_false"*",lid_closed,no_exception,"*
#		      1	       2       3           4       5

# means battery is charging,no matter of battery state, lid is closed, there is no exception and no matter of hibernation

# Separate with , and * means everything
# protect fixed variable with couple of " " like this : "discharging_true,status_low,lid_open,exception,"* or "discharging_false,"*",open,exception,"*

# Don't forget the first rule is the first apply.The first rule must be precise and the last one more general .
# You can put your own test at the end of NEW_STATE line in /usr/bin/laptop-script. Don't forget to make rules according to your new test.


case "$NEW_STATE" in

		       ######################################
		       #	        RULES		    #
		       ######################################

######################################### LID #######################################

## LID CLOSED ON AC : HIBERNATE 
"discharging_false,status_ok,lid_closed,no_exception,"* | "discharging_false,status_low,lid_closed,no_exception,"* )

LOG="Laptop-script : Lid closed on AC"

	$HIBERNATE_COMMAND &
	exit 1
;;

##  LID CLOSED ON AC WITH EXCEPTION (ushare or slimserver): SHUTDOWN SCREEN
"discharging_false,status_ok,lid_closed,exception,"* | "discharging_false,status_low,lid_closed,exception,"* )

LOG="Laptop-script : Lid closed on AC with exceptions"
	
	[[ -n `pgrep -u $LOGIN_NAME -f "ushare"` ]] || [[ -n "`pidof -x slimserver.pl`" ]] && \
	su $LOGIN_NAME -c  "XAUTHORITY=/home/$LOGIN_NAME/.Xauthority DISPLAY=:0 xset dpms force off" 
;;

## LID CLODES ON BATTERY: HIBERNATE
"discharging_true,status_ok,lid_closed,no_exception,"* | "discharging_true,low _battery,lid_closed,no_exception,"* )

LOG="Laptop-script : Lid closed on Battery"

	$HIBERNATE_COMMAND &
	exit 1
;;

##################################### EXCEPTIONS #####################################

## EXCEPTION ON AC: DPMS OFF
"discharging_false,status_ok,lid_open,exception,"* )

LOG="Laptop-script : Exceptions on AC"

	# DPMS OFF
	# [[ -n `pgrep xscreensaver` ]] && su $LOGIN_NAME -c  "XAUTHORITY=/home/$LOGIN_NAME/.Xauthority DISPLAY=:0 xscreensaver-command -exit" 
	su $LOGIN_NAME -c  "XAUTHORITY=/home/$LOGIN_NAME/.Xauthority DISPLAY=:0 xset -dpms"


;;

## EXCEPTION ON BATTERY BELOW LOW BATTERY: DPMS OFF
"discharging_true,status_low,lid_open,exception,"* )

LOG="Laptop-script : Exceptions below low battery"

	# DPMS OFF
	# [[ -n `pgrep xscreensaver` ]] && su $LOGIN_NAME -c  "XAUTHORITY=/home/$LOGIN_NAME/.Xauthority DISPLAY=:0 xscreensaver-command -exit" 
	su $LOGIN_NAME -c  "XAUTHORITY=/home/$LOGIN_NAME/.Xauthority DISPLAY=:0 xset -dpms"

;;

## EXEPTION ON BATTERY: DPMS OFF CPU GOVERNOR ON DEMAND
"discharging_true,status_ok,lid_open,exception,"* )

LOG="Laptop-script : Exceptions on Battery"
	
	# GOVERNOR CPU ON-DEMAND
	for cpu in  /sys/devices/system/cpu/cpu* ; do cpu_device=`basename $cpu`
	if [ -f /sys/devices/system/cpu/$cpu_device/cpufreq/scaling_governor ] ; then
	echo ondemand > /sys/devices/system/cpu/$cpu_device/cpufreq/scaling_governor 
	fi
	done

	# DPMS OFF
	#[[ -n `pgrep xscreensaver` ]] && su $LOGIN_NAME -c  "XAUTHORITY=/home/$LOGIN_NAME/.Xauthority DISPLAY=:0 xscreensaver-command -exit" 
	su $LOGIN_NAME -c  "XAUTHORITY=/home/$LOGIN_NAME/.Xauthority DISPLAY=:0 xset -dpms"

;;

###################################### INACTIVITY ###################################

## INACTIVTY ON AC: NOTHING
"discharging_false,status_ok,lid_open,no_exception,inactive" | "false,status_low,lid_open,no_exception,inactive"  )

LOG="Laptop-script : Hibernate on AC" ; TIME=0

	#$HIBERNATE_COMMAND &
	#exit 1
;;

## INACTIVITY ON BATTERY: HIBERNATE
"discharging_true,status_ok,lid_open,no_exception,inactive" | "discharging_true,status_low,lid_open,no_exception,inactive" )

LOG="Laptop-script : Hibernate on Battery" ; TIME=0

	$HIBERNATE_COMMAND &
	exit 1
;;

##################################### BATTERY LEVELS #################################

## ACTION ON LOW BATTERY: 
"discharging_true,status_low,lid_open,"* )

LOG="Laptop-script : Action on low Battery"

;;

## ACTION ON CRITICAL: BATTERY HIBERNATE
"discharging_true,status_critical,lid_open,"* )

LOG="Laptop-script : Action on critical Battery"

	$HIBERNATE_COMMAND &
	exit 1
;;

##################################### GENERAL RULES ##################################

				########### ON AC ############
	## Only for example, had your own powersaving tips according to your materials ##

"discharging_false,"* )

    LOG="Laptop-script : General rules on AC"


	# GOVERNOR CPU ON-DEMAND
	for cpu in  /sys/devices/system/cpu/cpu* ; do cpu_device=`basename $cpu`
	if [ -f /sys/devices/system/cpu/$cpu_device/cpufreq/scaling_governor ] ; then
	echo ondemand > /sys/devices/system/cpu/$cpu_device/cpufreq/scaling_governor 
	fi
	done
	
	# MULTI CORE SCHEDULER
	#echo 0 > /sys/devices/system/cpu/sched_mc_power_savings

	# HARD DRIVE POWERMANAGEMENT
	
	#The relevant options for hdparm are:
	# -B   set Advanced Power Management setting (1-255)
	# -S   set standby (spindown) timeout
	# -y   put IDE drive in standby mode
	# -Y   put IDE drive to sleep
	# -Z   disable Seagate auto-powersaving mode

	# hdparm -W 1 -S 0 -B 254 -M 0 /dev/sda  &> /dev/null
	
	# HARD DRIVE ATIME AND DIRATIME
	# mount -o remount,relatime /

	# SCREENSAVER
	[[ $WORKAROUND_HACK == "yes" ]] && su $LOGIN_NAME -c  "XAUTHORITY=/home/$LOGIN_NAME/.Xauthority DISPLAY=:0 xset dpms 0 0 $DPMS_STANDBY_AC"
	# [[ -z `pidof xscreensaver` ]] && [[ $WORKAROUND_HACK == "yes" ]] && su $LOGIN_NAME -c "XAUTHORITY=/home/$LOGIN_NAME/.Xauthority DISPLAY=:0 xscreensaver -nosplash &"

	# Backlight
	[[ $WORKAROUND_HACK == "yes" ]] && echo 7 > /sys/devices/virtual/backlight/acpi_video0/device/thermal_cooling/cur_state
	
	# MULTI CORE SCHEDULER
	#echo 0 > /sys/devices/system/cpu/sched_smt_power_savings
	#echo  0 > /sys/devices/system/cpu/sched_mc_power_savings 

	# WIFI
	#iwpriv eth1 set_power 6
	#modprobe ipw2200

	# RKILL
	#for i in `find /sys -name "rf_kill" ; do echo 0 > $i ; done

	# ETHERNET WAKE ON LAN
	# ethtool -s eth0 wol p

	# ALSA SOUND POWERSAVE
	# echo 0 > /sys/module/snd_ac97_codec/parameters/power_save
	# echo 0 > /sys/module/snd_hda_intel/parameters/power_save 
	
	# HARD DISK WRITING
	# echo 500 > /proc/sys/vm/dirty_writeback_centisecs

	# VM power saving
	# echo 0 > /proc/sys/vm/laptop_mode

	# SWAP
	# sysctl vm.swappiness=20	&> /dev/null
	
	# CD-ROM polling
	# hal-disable-polling --enable-polling --device /dev/scd0 &> /dev/null

	#USB
	#for usb_device in /sys/bus/usb/devices/* ; do
	#usb_device=`basename $usb_device`
	#if [ -f /sys/bus/usb/devices/$usb_device/power/autosuspend ]; then
	#echo 0 > /sys/bus/usb/devices/$usb_device/power/autosuspend;
	#fi
	#done

	# CUPS
	# [[ -z `pidof cups` ]] && /etc/rc.d/cups start &> /dev/null

	# CRON
	# [[ -z `pidof crond` ]] && /etc/rc.d/crond start &> /dev/null
;;

				######## ON BATTERY ############
	## Only for example, had your own powersaving tips according to your materials ##

"discharging_true,"* )

    LOG="Laptop-script : General rules on Battery"

	#GOVERNOR CPU conservative
	for cpu in  /sys/devices/system/cpu/cpu* ; do cpu_device=`basename $cpu`
	if [ -f /sys/devices/system/cpu/$cpu_device/cpufreq/scaling_governor ] ; then
	echo conservative > /sys/devices/system/cpu/$cpu_device/cpufreq/scaling_governor 
	fi
	done


	# MULTI CORE SCHEDULER
	#echo 1 > /sys/devices/system/cpu/sched_mc_power_savings

	# HARD DRIVE POWERMANAGEMENT

	#The relevant options for hdparm are:
	# -B   set Advanced Power Management setting (1-255)
	# -S   set standby (spindown) timeout
	# -y   put IDE drive in standby mode
	# -Y   put IDE drive to sleep
	# -Z   disable Seagate auto-powersaving mode

	# hdparm -W 0 -S 6 -B 1 -M 254 /dev/sda	&> /dev/null

	# HARD DRIVE ATIME AND DIRATIME
	# mount -o remount,noatime,nodiratime /

	# SCREENSAVER
	# [[ -n `pidof xscreensaver` ]] && [[ $WORKAROUND_HACK == "yes" ]] && su $LOGIN_NAME -c "XAUTHORITY=/home/$LOGIN_NAME/.Xauthority DISPLAY=:0 xscreensaver-command -exit"  
	[[ $WORKAROUND_HACK == "yes" ]] && su $LOGIN_NAME -c  "XAUTHORITY=/home/$LOGIN_NAME/.Xauthority DISPLAY=:0 xset dpms 0 0 $DPMS_STANDBY_BATT "
	
	# Backlight
	[[ $WORKAROUND_HACK == "yes" ]] && echo 5 > /sys/devices/virtual/backlight/acpi_video0/device/thermal_cooling/cur_state

	# MULTI CORE SCHEDULER
	#echo 1 > /sys/devices/system/cpu/sched_smt_power_savings
	#echo 1 > /sys/devices/system/cpu/sched_mc_power_savings 

	# SATA
	#for host in  /sys/class/scsi_host/host* ; do host_device=`basename $host`
	#echo min_power > /sys/class/scsi_host/$host_device/link_power_management_policy
	#done

	# WIFI
	#iwpriv eth1 set_power 5
	#rmmod ipw2200
	#modprobe ipw2200 associate=0

	# RFKILL
	#for i in `find /sys -name "rf_kill" ; do echo 1 > $i ; done

	# ETHERNET WAKE ON LAN
	# ethtool -s eth0 wol d

	# ALSA SOUND POWERSAVE
	# echo 1 > /sys/module/snd_ac97_codec/parameters/power_save
	# echo 1 > /sys/module/snd_hda_intel/parameters/power_save 
	
	# HARD DISK WRITING
	# echo 1500 > /proc/sys/vm/dirty_writeback_centisecs

	# SWAP
	# sysctl vm.swappiness=0 &> /dev/null

	# VM power saving
	# echo 5 > /proc/sys/vm/laptop_mode

	# CD-ROM polling
	# hal-disable-polling --device /dev/scd0 &> /dev/null

	# USB
	# for usb_device in /sys/bus/usb/devices/* ; do
	# usb_device=`basename $usb_device`
	# if [ -f /sys/bus/usb/devices/$usb_device/power/autosuspend ]; then 
	# echo 2 > /sys/bus/usb/devices/$usb_device/power/autosuspend;
	# fi

	# if [ -f /sys/bus/usb/devices/$usb_device/power/control ]; then 
	# echo "auto" > /sys/bus/usb/devices/$usb_device/power/control;
				 
	# elif [ -f /sys/bus/usb/devices/$usb_device/power/level ]; then 
	# echo "auto" > /sys/bus/usb/devices/$usb_device/power/level;
	# fi
	# done
	
	#PM
	# for device in /sys/bus/pci/devices/*; do
	# if [ -f $device/power/control ]; then	echo "auto" > $device/power/control;
	# fi
	# done

	# CUPS
	# [[ -n `pidof cups` ]] && /etc/rc.d/cups stop &> /dev/null

	# CRON
	# [[ -n `pidof crond` ]] && /etc/rc.d/crond stop &> /dev/null
;;


##################################### LOG ON ERROR ######################################

*) logger -p daemon.crit "### Error, rule not found! Policy state : $NEW_STATE ### "
;;

esac

